SlidableController class

Represents a way to control a slidable from outside.

Constructors

SlidableController(TickerProvider vsync)
Creates a SlidableController.

Properties

actionPaneConfigurator ↔ RatioConfigurator?
The current action pane configurator.
getter/setter pair
actionPaneType → ValueNotifier<ActionPaneType>
Track the type of the action pane.
final
animation → Animation<double>
The value of the ratio over time.
no setter
closing → bool
Whether this close() method has been called and not finished.
no setter
direction → ValueNotifier<int>
Track the direction in which the slidable moves.
final
dismissGesture → ValueNotifier<DismissGesture?>
Track the dismiss gestures.
no setter
enableEndActionPane ↔ bool
Whether the end action pane is enabled.
getter/setter pair
enableNegativeActionPane → bool
Whether the negative action pane is enabled.
no setter
enablePositiveActionPane → bool
Whether the positive action pane is enabled.
no setter
enableStartActionPane ↔ bool
Whether the start action pane is enabled.
getter/setter pair
endActionPaneExtentRatio ↔ double
The extent ratio of the end action pane.
getter/setter pair
endGesture → ValueNotifier<EndGesture?>
Track the end gestures.
final
hashCode → int
The hash code for this object.
no setterinherited
isDismissibleReady → bool
Indicates whether the dismissible registered to gestures.
no setter
isLeftToRight ↔ bool
Whether the start action pane is at the left (if horizontal). Defaults to true.
getter/setter pair
ratio ↔ double
The current ratio of the full size of the Slidable that is already dragged.
getter/setter pair
resizeRequest → ValueNotifier<ResizeRequest?>
Track the resize requests.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startActionPaneExtentRatio ↔ double
The extent ratio of the start action pane.
getter/setter pair

Methods

close({Duration duration = _defaultMovementDuration, Curve curve = _defaultCurve}) → Future<void>
Closes the Slidable.
dismiss(ResizeRequest request, {Duration duration = _defaultMovementDuration, Curve curve = _defaultCurve}) → Future<void>
Dismisses the Slidable.
dispatchEndGesture(double? velocity, GestureDirection direction) → void
Dispatches a new EndGesture determined by the given velocity and direction.
dispose() → void
Disposes the controller.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openCurrentActionPane({Duration duration = _defaultMovementDuration, Curve curve = _defaultCurve}) → Future<void>
Opens the current ActionPane.
openEndActionPane({Duration duration = _defaultMovementDuration, Curve curve = _defaultCurve}) → Future<void>
Opens the Slidable.endActionPane.
openStartActionPane({Duration duration = _defaultMovementDuration, Curve curve = _defaultCurve}) → Future<void>
Opens the Slidable.startActionPane.
openTo(double ratio, {Duration duration = _defaultMovementDuration, Curve curve = _defaultCurve}) → Future<void>
Opens the Slidable to the given ratio.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited